@@ -33,9 +33,10 @@
 #  define KUNITCONVERSION_DEPRECATED_NO_EXPORT KUNITCONVERSION_NO_EXPORT KUNITCONVERSION_DEPRECATED
 #endif
 
-#define DEFINE_NO_DEPRECATED 0
-#if DEFINE_NO_DEPRECATED
-# define KUNITCONVERSION_NO_DEPRECATED
+#if 0 /* DEFINE_NO_DEPRECATED */
+#  ifndef KUNITCONVERSION_NO_DEPRECATED
+#    define KUNITCONVERSION_NO_DEPRECATED
+#  endif
 #endif
 
 #endif
